searchData={"items":[{"type":"module","title":"MNDP","doc":"An Elixir implementation for the [MikroTik Neighbor Discovery Protocol](https://help.mikrotik.com/docs/display/ROS/Neighbor+discovery).\n\n\nDiscover devices\n\n```bash\n> mix mndp.discover\n\nPress any key to end\n\n┌───────┬──────┬────────────────┬─────────┬─────────────┬─────────┬───────────┐\n│VERSION│UPTIME│MAC             │LAST SEEN│IPV4         │INTERFACE│IDENTITY   │\n├───────┼──────┼────────────────┼─────────┼─────────────┼─────────┼───────────┤\n│0.1.0  │4396  │6:95:72:B0:80:BB│0s ago   │172.31.199.73│usb0     │nerves-2a0c│\n└───────┴──────┴────────────────┴─────────┴─────────────┴─────────┴───────────┘\n```\n\nThe application is automatically started and listening and broadcasting on all available IPv4 network interfaces. You can restrict the interfaces via config. See `MNDP.Options`. To use it just add the dependency to your project.\n\n```elixir\ndef deps do\n  [\n    {:mndp, \"~> 0.1.0\"}\n  ]\nend\n```\n\nTo get the last discovered devices you can use `MNDP.Listener.list_discovered/0`.\n\nYou can decode and encode from and to a binary directly.\n\nEncoding: \n\n```elixir\niex> MNDP.new!(\"en0\") |> MNDP.encode()\n<<...>>\n```\n\nDecoding: \n\n```elixir\niex> MNDP.decode(binary)\n{:ok, %MNDP{}}\n```","ref":"MNDP.html"},{"type":"function","title":"MNDP.decode/1","doc":"Decdes a binary to a `MNDP` struct.\n\nThe structure of a MNDP packet looks like this\n\n    0                   1                   2                   3\n    0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n    +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n    |     TYPE      |      TTL      |              SEQ              |\n    +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n    |           TLV TYPE            |          TLV LENGTH           |\n    +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n    |                                                               |\n    +                           TLV DATA                            +\n    |                                                               |\n    +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n* TYPE (8 bytes)\n* TTL (8 bytes)\n* SEQ (16 bytes)\n* TLV TYPE (16 bytes)\n* TLV LENGTH (16 bytes)\n* TLV DATA (TLV LENGTH)\n\n> #### Info {: .info}\n>\n> The header fields are set like this in RouterOS 6 but changes in RouterOS 7. Currently it is not guaranteed to be correct","ref":"MNDP.html#decode/1"},{"type":"function","title":"Examples - MNDP.decode/1","doc":"iex> MNDP.decode(<<_>>)\n    {:ok, %MNDP{}}\n\n    iex> MNDP.decode(<<\"unknown\">>)\n    {:error, :expected_tlv_format}","ref":"MNDP.html#decode/1-examples"},{"type":"function","title":"MNDP.encode/1","doc":"Ecnodes an `MNDP` stuct to a binary","ref":"MNDP.html#encode/1"},{"type":"function","title":"Examples - MNDP.encode/1","doc":"iex> MNDP.encode(%MNDP{})\n    <<...>>","ref":"MNDP.html#encode/1-examples"},{"type":"function","title":"MNDP.list_discovered/0","doc":"List all the discovered devices withing configured TTL. See `MNDP.Options` for informations about how to modify the default settings","ref":"MNDP.html#list_discovered/0"},{"type":"function","title":"MNDP.new/2","doc":"Creates a new MNDP struct from an interface name or struct.","ref":"MNDP.html#new/2"},{"type":"function","title":"Examples - MNDP.new/2","doc":"iex> MNDP.new(\"en0\")\n    {:ok, %MNDP{}}\n\n    iex> MNDP.new(\"unknown interface\")\n    {:error, :interface_not_found}","ref":"MNDP.html#new/2-examples"},{"type":"function","title":"MNDP.new!/2","doc":"Same as `MNDP.new/2` but raises on error","ref":"MNDP.html#new!/2"},{"type":"function","title":"MNDP.print_discovered/0","doc":"Will print the devices from `list_discovered/0` via `IO.puts`","ref":"MNDP.html#print_discovered/0"},{"type":"function","title":"MNDP.subscribe/0","doc":"Subscribe the current process to new MNDP packets from the listener. It will send a message with the type `{:mndp, MNDP.t()}`\n\nUsusally you do this in a process like a GenServer and the message can be handled like this\n\n      def handle_info({:mndp, %MNDP{} = mndp}, state) do\n        IO.inspect(mndp)\n        {:noreply, state}\n      end\n\nIf you subscribe from an `IEx` shell you can flush the received messages with `IEx.Helpers.flush/0`. It is automatically imported and can be called with just `flush()`","ref":"MNDP.html#subscribe/0"},{"type":"type","title":"MNDP.mac/0","doc":"representation of a hardware MAC address","ref":"MNDP.html#t:mac/0"},{"type":"type","title":"MNDP.overrides/0","doc":"field overrides for the MNDP struct generation","ref":"MNDP.html#t:overrides/0"},{"type":"type","title":"MNDP.t/0","doc":"a MNDP packet struct","ref":"MNDP.html#t:t/0"},{"type":"type","title":"MNDP.uptime/0","doc":"seconds since start","ref":"MNDP.html#t:uptime/0"},{"type":"module","title":"MNDP.CLI","doc":"","ref":"MNDP.CLI.html"},{"type":"function","title":"MNDP.CLI.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"MNDP.CLI.html#child_spec/1"},{"type":"function","title":"MNDP.CLI.run/0","doc":"","ref":"MNDP.CLI.html#run/0"},{"type":"function","title":"MNDP.CLI.start_link/1","doc":"","ref":"MNDP.CLI.html#start_link/1"},{"type":"module","title":"MNDP.CoreMonitor","doc":"Core logic for network monitors\n\nThis module contains most of the logic needed for writing a network monitor.\nIt's only intended to be called from `MNDP.InetMonitor` and\n`MNDP.VintageNetMonitor`.","ref":"MNDP.CoreMonitor.html"},{"type":"function","title":"MNDP.CoreMonitor.flush_todo_list/1","doc":"","ref":"MNDP.CoreMonitor.html#flush_todo_list/1"},{"type":"function","title":"MNDP.CoreMonitor.init/1","doc":"","ref":"MNDP.CoreMonitor.html#init/1"},{"type":"function","title":"MNDP.CoreMonitor.set_ip_list/3","doc":"","ref":"MNDP.CoreMonitor.html#set_ip_list/3"},{"type":"function","title":"MNDP.CoreMonitor.unset_remaining_ifnames/2","doc":"","ref":"MNDP.CoreMonitor.html#unset_remaining_ifnames/2"},{"type":"type","title":"MNDP.CoreMonitor.option/0","doc":"Monitor options\n\n* `:excluded_ifnames` - a list of network interface names to ignore","ref":"MNDP.CoreMonitor.html#t:option/0"},{"type":"module","title":"MNDP.InetMonitor","doc":"Network monitor that uses Erlang's :inet functions\n\nUse this network monitor to detect new network interfaces and their\nIP addresses when not using Nerves. It regularly polls the system\nfor changes so it's not as fast at starting MNDP servers as\nthe `MNDP.VintageNetCoreMonitor` is. However, it works everywhere.\n\nSee `MNDP.Options` for how to set your `config.exs` to use it.","ref":"MNDP.InetMonitor.html"},{"type":"function","title":"MNDP.InetMonitor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"MNDP.InetMonitor.html#child_spec/1"},{"type":"module","title":"MNDP.Interface","doc":"","ref":"MNDP.Interface.html"},{"type":"function","title":"MNDP.Interface.from_ifname/1","doc":"","ref":"MNDP.Interface.html#from_ifname/1"},{"type":"type","title":"MNDP.Interface.t/0","doc":"","ref":"MNDP.Interface.html#t:t/0"},{"type":"module","title":"MNDP.Listener","doc":"Listener for broadcasted MNDP packets.\n\nMNDP packets typically get send to the global broadcast address `255.255.255.255`. To receive all of these broadcasts, the listener binds on the configured port to `0.0.0.0`.\n\nTo get notified when new packets get received, you can use `MNDP.subscribe/0`.","ref":"MNDP.Listener.html"},{"type":"function","title":"MNDP.Listener.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"MNDP.Listener.html#child_spec/1"},{"type":"function","title":"MNDP.Listener.list_discovered/0","doc":"","ref":"MNDP.Listener.html#list_discovered/0"},{"type":"function","title":"MNDP.Listener.start_link/1","doc":"","ref":"MNDP.Listener.html#start_link/1"},{"type":"type","title":"MNDP.Listener.opts/0","doc":"","ref":"MNDP.Listener.html#t:opts/0"},{"type":"type","title":"MNDP.Listener.port_number/0","doc":"","ref":"MNDP.Listener.html#t:port_number/0"},{"type":"module","title":"MNDP.Options","doc":"MNDP options\n\nMNDP is usually configured in a project's application environment\n(`config.ex`). If you don't set any configuration, this is the default:\n\n```elixir\nconfig :mndp,\n  identity: :hostname,\n  interval: :timer.seconds(30),\n  ttl: :timer.minutes(1),\n  port: 5678,\n  excluded_ifnames: [\"lo0\", \"lo\", \"bridge0\", \"ppp0\", \"wwan0\", \"__unknown\"],\n  if_monitor: MNDP.VintageNetMonitor #if vintage_net is available, will fall back to `MNDP.InetMonitor`\n```\n\nThe configurable keys are:\n\n* `:identity` - A name set in the discovery packet. Per default this is set to `:hostname`\n* `:ttl` - The default MNDP record time-to-live for discovered devices. The default of 60\n  seconds is probably fine for most use. \n* `:excluded_ifnames` - A list of network interfaces names to ignore. By\n  default, `MNDP` will ignore loopback and cellular network interfaces.\n* `:if_monitor` - Set to `MNDP.VintageNetMonitor` when using Nerves or\n  `MNDP.InetMonitor` elsewhere.  The default is `MNDP.VintageNetMonitor`.\n\nSome options are modifiable at runtime. Functions for modifying these are in\nthe `MNDP` module.","ref":"MNDP.Options.html"},{"type":"module","title":"MNDP.Packet","doc":"Functions for decoding and encoding the raw packet binary","ref":"MNDP.Packet.html"},{"type":"function","title":"MNDP.Packet.decode/1","doc":"","ref":"MNDP.Packet.html#decode/1"},{"type":"function","title":"MNDP.Packet.encode/1","doc":"","ref":"MNDP.Packet.html#encode/1"},{"type":"module","title":"MNDP.Render","doc":"Helpers for rendering the MNDP struct","ref":"MNDP.Render.html"},{"type":"function","title":"MNDP.Render.print_discovered/0","doc":"","ref":"MNDP.Render.html#print_discovered/0"},{"type":"module","title":"MNDP.Sender","doc":"Sender to broadcast MNDP packets.\n\nThe `Sender` will be typically started and stopped by the interface monitors (`MNDP.InetMonitor` or `MNDP.VintageNetMonitor`). \nIt will one process for each IP address for each interface.\nTo exclude interfaces from this automation, see `MNDP.Options`.\n\nTo start and stop a `MNDP.Server` manually the interface name and IP address to bind to is needed","ref":"MNDP.Sender.html"},{"type":"module","title":"Examples - MNDP.Sender","doc":"iex> MNDP.Server.start_link({\"en0\", {10, 0, 0, 199}})\n    {:ok, pid}\n\n    iex> MNDP.Server.stop_server(\"en0\", {10, 0, 0, 199})\n    :ok","ref":"MNDP.Sender.html#module-examples"},{"type":"function","title":"MNDP.Sender.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"MNDP.Sender.html#child_spec/1"},{"type":"function","title":"MNDP.Sender.start_link/1","doc":"","ref":"MNDP.Sender.html#start_link/1"},{"type":"module","title":"MNDP.VintageNetMonitor","doc":"Network monitor that using VintageNet\n\nUse this network monitor to detect new network interfaces and their\nIP addresses when using Nerves. It is the default.","ref":"MNDP.VintageNetMonitor.html"},{"type":"function","title":"MNDP.VintageNetMonitor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"MNDP.VintageNetMonitor.html#child_spec/1"},{"type":"function","title":"MNDP.VintageNetMonitor.start_link/1","doc":"","ref":"MNDP.VintageNetMonitor.html#start_link/1"},{"type":"task","title":"mix mndp.discover","doc":"Discovers Devices with MNDP","ref":"Mix.Tasks.Mndp.Discover.html"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased] \n\n## [0.1.1] - 2024-10-14","ref":"changelog.html"},{"type":"extras","title":"Changed - Changelog","doc":"- mix tasked namespaced from `mix discover` to `mix mndp.discover`","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- use hex package in docs #4\n- fix typo in configuration example #5\n- update spec to allow `:hostname` for the identity field #6\n\n## [0.1.0] - 2024-10-13","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Initial Version","ref":"changelog.html#added"},{"type":"extras","title":"MNDP - MikroTik Neighbor Discovery Protocol","doc":"# MNDP - MikroTik Neighbor Discovery Protocol\n\n<!-- MDOC !-->\n\nAn Elixir implementation for the [MikroTik Neighbor Discovery Protocol](https://help.mikrotik.com/docs/display/ROS/Neighbor+discovery).\n\n\nDiscover devices\n\n```bash\n> mix mndp.discover\n\nPress any key to end\n\n┌───────┬──────┬────────────────┬─────────┬─────────────┬─────────┬───────────┐\n│VERSION│UPTIME│MAC             │LAST SEEN│IPV4         │INTERFACE│IDENTITY   │\n├───────┼──────┼────────────────┼─────────┼─────────────┼─────────┼───────────┤\n│0.1.0  │4396  │6:95:72:B0:80:BB│0s ago   │172.31.199.73│usb0     │nerves-2a0c│\n└───────┴──────┴────────────────┴─────────┴─────────────┴─────────┴───────────┘\n```\n\nThe application is automatically started and listening and broadcasting on all available IPv4 network interfaces. You can restrict the interfaces via config. See `MNDP.Options`. To use it just add the dependency to your project.\n\n```elixir\ndef deps do\n  [\n    {:mndp, \"~> 0.1.0\"}\n  ]\nend\n```\n\nTo get the last discovered devices you can use `MNDP.Listener.list_discovered/0`.\n\nYou can decode and encode from and to a binary directly.\n\nEncoding: \n\n```elixir\niex> MNDP.new!(\"en0\") |> MNDP.encode()\n<<...>>\n```\n\nDecoding: \n\n```elixir\niex> MNDP.decode(binary)\n{:ok, %MNDP{}}\n```\n\n<!-- MDOC !-->","ref":"readme.html"},{"type":"extras","title":"Todo / Ideas - MNDP - MikroTik Neighbor Discovery Protocol","doc":"- [ ] Fix ignored warnings in `.dialyzer_ignore.exs`\n- [ ] Sequence numbering\n- [ ] Answer discovery requests with correct `MNDP.Server` when received in `MNDP.Listener`\n- [ ] Make everything configurable\n- [ ] Add tests\n- [ ] Better Logging\n- [ ] Check licence\n- [ ] With 0.1.0 add CHANGELOG\n- [x] Subscribe API\n- [x] Recognize when iface is down in `MNDP.InetMonitor`\n- [x] Add docs","ref":"readme.html#todo-ideas"},{"type":"extras","title":"Installation - MNDP - MikroTik Neighbor Discovery Protocol","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `mndp` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:mndp, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Heavily inspired by - MNDP - MikroTik Neighbor Discovery Protocol","doc":"- [https://github.com/nerves-networking/mdns_lite](MdnsLite)","ref":"readme.html#heavily-inspired-by"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}